@@ -42,10 +42,10 @@
 #include "checks/manuallevel/qt-keywords.h"
 #include "checks/manuallevel/qt4-qstring-from-array.h"
 #include "checks/manuallevel/qt6-deprecated-api-fixes.h"
+#include "checks/manuallevel/qt6-fwd-fixes.h"
 #include "checks/manuallevel/qt6-header-fixes.h"
 #include "checks/manuallevel/qt6-qhash-signature.h"
 #include "checks/manuallevel/qt6-qlatin1stringchar-to-u.h"
-#include "checks/manuallevel/qt6-fwd-fixes.h"
 #include "checks/manuallevel/qvariant-template-instantiation.h"
 #include "checks/manuallevel/raw-environment-function.h"
 #include "checks/manuallevel/reserve-candidates.h"
@@ -99,7 +99,8 @@
 #include "checks/level1/qlatin1string-non-ascii.h"
 #include "checks/level1/qproperty-without-notify.h"
 #include "checks/level1/qstring-left.h"
-#include "checks/level1/range-loop.h"
+#include "checks/level1/range-loop-detach.h"
+#include "checks/level1/range-loop-reference.h"
 #include "checks/level1/returning-data-from-temporary.h"
 #include "checks/level1/rule-of-two-soft.h"
 #include "checks/level1/skipped-base-method.h"
@@ -147,14 +148,14 @@ void CheckManager::registerChecks()
     registerFixIt(1, "fix-qt4-qstring-from-array", "qt4-qstring-from-array");
     registerCheck(check<Qt6DeprecatedAPIFixes>("qt6-deprecated-api-fixes", ManualCheckLevel,  RegisteredCheck::Option_VisitsStmts | RegisteredCheck::Option_VisitsDecls));
     registerFixIt(1, "fix-qt6-deprecated-api-fixes", "qt6-deprecated-api-fixes");
+    registerCheck(check<Qt6FwdFixes>("qt6-fwd-fixes", ManualCheckLevel,  RegisteredCheck::Option_VisitsDecls));
+    registerFixIt(1, "fix-qt6-fwd-fixes", "qt6-fwd-fixes");
     registerCheck(check<Qt6HeaderFixes>("qt6-header-fixes", ManualCheckLevel,  RegisteredCheck::Option_VisitsStmts));
     registerFixIt(1, "fix-qt6-header-fixes", "qt6-header-fixes");
     registerCheck(check<Qt6QHashSignature>("qt6-qhash-signature", ManualCheckLevel,  RegisteredCheck::Option_VisitsStmts | RegisteredCheck::Option_VisitsDecls));
     registerFixIt(1, "fix-qt6-qhash-signature", "qt6-qhash-signature");
     registerCheck(check<Qt6QLatin1StringCharToU>("qt6-qlatin1stringchar-to-u", ManualCheckLevel,  RegisteredCheck::Option_VisitsStmts));
     registerFixIt(1, "fix-qt6-qlatin1stringchar-to-u", "qt6-qlatin1stringchar-to-u");
-    registerCheck(check<Qt6FwdFixes>("qt6-fwd-fixes", ManualCheckLevel, RegisteredCheck::Option_VisitsDecls));
-    registerFixIt(1, "fix-qt6-fwd-fixes", "qt6-fwd-fixes");
     registerCheck(check<QVariantTemplateInstantiation>("qvariant-template-instantiation", ManualCheckLevel,  RegisteredCheck::Option_VisitsStmts));
     registerCheck(check<RawEnvironmentFunction>("raw-environment-function", ManualCheckLevel,  RegisteredCheck::Option_VisitsStmts));
     registerCheck(check<ReserveCandidates>("reserve-candidates", ManualCheckLevel,  RegisteredCheck::Option_VisitsStmts));
@@ -214,9 +215,10 @@ void CheckManager::registerChecks()
     registerCheck(check<QLatin1StringNonAscii>("qlatin1string-non-ascii", CheckLevel1,  RegisteredCheck::Option_VisitsStmts));
     registerCheck(check<QPropertyWithoutNotify>("qproperty-without-notify", CheckLevel1,  RegisteredCheck::Option_VisitsStmts));
     registerCheck(check<QStringLeft>("qstring-left", CheckLevel1,  RegisteredCheck::Option_VisitsStmts));
-    registerCheck(check<RangeLoop>("range-loop", CheckLevel1,  RegisteredCheck::Option_VisitsStmts));
-    registerFixIt(1, "fix-range-loop-add-ref", "range-loop");
-    registerFixIt(2, "fix-range-loop-add-qasconst", "range-loop");
+    registerCheck(check<RangeLoopDetach>("range-loop-detach", CheckLevel1,  RegisteredCheck::Option_VisitsStmts));
+    registerFixIt(1, "fix-range-loop-add-qasconst", "range-loop-detach");
+    registerCheck(check<RangeLoopReference>("range-loop-reference", CheckLevel1,  RegisteredCheck::Option_VisitsStmts));
+    registerFixIt(1, "fix-range-loop-add-ref", "range-loop-reference");
     registerCheck(check<ReturningDataFromTemporary>("returning-data-from-temporary", CheckLevel1,  RegisteredCheck::Option_VisitsStmts));
     registerCheck(check<RuleOfTwoSoft>("rule-of-two-soft", CheckLevel1,  RegisteredCheck::Option_VisitsStmts));
     registerCheck(check<SkippedBaseMethod>("skipped-base-method", CheckLevel1,  RegisteredCheck::Option_VisitsStmts));
