@@ -26,9 +26,11 @@
 #include <clang/AST/Attr.h>
 #include <clang/AST/Expr.h>
 #include <clang/AST/Decl.h>
+#include <clang/AST/DeclCXX.h>
 #include <clang/Basic/SourceLocation.h>
 #include <clang/Basic/SourceManager.h>
 #include <clang/Frontend/FrontendDiagnostic.h>
+#include <clang/Lex/Lexer.h>
 #include <clang/Tooling/Core/Diagnostic.h>
 
 #if defined(CLAZY_USES_BOOST_REGEX)
@@ -103,6 +105,40 @@ inline clang::tooling::Replacements& DiagnosticFix(clang::tooling::Diagnostic &d
 #endif
 }
 
+inline auto getBuffer(const clang::SourceManager &sm, clang::FileID id, bool *invalid)
+{
+#if LLVM_VERSION_MAJOR >= 12
+    auto buffer = sm.getBufferOrNone(id);
+    *invalid = !buffer.hasValue();
+    return buffer;
+#else
+    return sm.getBuffer(id, invalid);
+#endif
+}
+
+#if LLVM_VERSION_MAJOR >= 12
+inline clang::Lexer getLexer(clang::FileID id, llvm::Optional<llvm::MemoryBufferRef> inputFile,
+                             const clang::SourceManager &sm, const clang::LangOptions &lo)
+{
+    return clang::Lexer(id, inputFile.getValue(), sm, lo);
+}
+#else
+inline clang::Lexer getLexer(clang::FileID id, const llvm::MemoryBuffer *inputFile,
+                             const clang::SourceManager &sm, const clang::LangOptions &lo)
+{
+    return clang::Lexer(id, inputFile, sm, lo);
+}
+#endif
+
+inline bool isFinal(const clang::CXXRecordDecl *record)
+{
+#if LLVM_VERSION_MAJOR >= 11
+    return record->isEffectivelyFinal();
+#else
+    return record->hasAttr<clang::FinalAttr>();
+#endif
+}
+
 }
 
 #endif
